*************************************************************************
* GPT.ASM                                                               *
*                                                                       *
* GPT initialization template                                           *
* Mark Underwood 9/28/1993                                              *
* (C) 1993 Maxim Integrated Products                                    *
*                                                                       *
* Written for use with the Motorola 68HC Macro Assembler - Vers. 4.1    *
*                                                                       *
* A template for programming the 68HC16 Module's                        *
* General Purpose Timer and I/O port.                                   *
*                                                                       *
*************************************************************************
GPTMCR  EQU $F900
GPTMTR  EQU $F902
ICR     EQU $F904
PDDR    EQU $F906
GPTPDR  EQU $F907
OC1M    EQU $F908
OC1D    EQU $F909
TCNT    EQU $F90A
PACTL   EQU $F90C
PACNT   EQU $F90D
TIC1    EQU $F90E
TIC2    EQU $F910
TIC3    EQU $F912
TOC1    EQU $F914
TOC2    EQU $F916
TOC3    EQU $F918
TOC4    EQU $F91A
TI4O5   EQU $F91C
TCTL1   EQU $F91E
TCTL2   EQU $F91F
TMSK1   EQU $F920
TMSK2   EQU $F921
TFLG1   EQU $F922
TFLG2   EQU $F923
CFORC   EQU $F924
PWMC    EQU $F925
PWMA    EQU $F926
PWMB    EQU $F927
PWMCNT  EQU $F928
PWMBUFA EQU $F92A
PWMBUFB EQU $F92B
PRESCL  EQU $F92C
*
* ; list of output pins and pins that are initially high
* LDD  #OUTIC1+OUTIC2+OUTIC3+OUTIC4+OUTOC1+OUTOC2+OUTOC3+OUTOC4+PINIC1+PINIC2+PINIC3+PINIC4+PINOC1+PINOC2+PINOC3+PINOC4
* STD  PDDR
*
PINIC1  EQU $01
PINIC2  EQU $02
PINIC3  EQU $04
PINOC1  EQU $08
PINOC2  EQU $10
PINOC3  EQU $20
PINOC4  EQU $40
PINIC4  EQU $80
OUTIC1  EQU $0100
OUTIC2  EQU $0200
OUTIC3  EQU $0400
OUTOC1  EQU $0800
OUTOC2  EQU $1000
OUTOC3  EQU $2000
OUTOC4  EQU $4000
OUTIC4  EQU $8000
*
* ; output compare / timer actions (OC5 is same pin as IC4)
* LDAA #OC2NOP+OC3NOP+OC4NOP+OC5NOP
* STAA TCTL1
*
OC2NOP          EQU $00
OC2TOGGLE       EQU $01
OC2CLEAR        EQU $02
OC2SET          EQU $03
OC3NOP          EQU $00
OC3TOGGLE       EQU $04
OC3CLEAR        EQU $08
OC3SET          EQU $0C
OC4NOP          EQU $00
OC4TOGGLE       EQU $10
OC4CLEAR        EQU $20
OC4SET          EQU $30
OC5NOP          EQU $00
OC5TOGGLE       EQU $40
OC5CLEAR        EQU $80
OC5SET          EQU $C0
*
* ; input capture / interrupt trigger edge control
* LDAA #(IC1RISING+IC1FALLING)+(IC2RISING+IC2FALLING)+(IC3RISING+IC3FALLING)+(IC4RISING+IC4FALLING)
* STAA TCTL2              ; GPT Input Capture edge control
*
IC1RISING  EQU $01
IC1FALLING EQU $02
IC2RISING  EQU $04
IC2FALLING EQU $08
IC3RISING  EQU $10
IC3FALLING EQU $20
IC4RISING  EQU $40
IC4FALLING EQU $80
*
* ; set timer prescaler
* LDD  #(CPR&$0007)
* STD  TMSK1
*
* ; interrupt enable mask
* LDD  TMSK1
* ORD  #(EnableIntIC1+EnableIntIC2+EnableIntIC3+EnableIntIC4)   ; enable
* ANDD #~(EnableIntIC1+EnableIntIC2+EnableIntIC3+EnableIntIC4)  ; disable
* STD  TMSK1
*
* ; timer interrupt flags
* LDD  TFLG1
* ORD  #(EnableIntIC1+EnableIntIC2+EnableIntIC3+EnableIntIC4)   ; enable
* ANDD #~(EnableIntIC1+EnableIntIC2+EnableIntIC3+EnableIntIC4)  ; disable
* STD  TFLG1
*
EnableIntIC1   EQU $0100  ; interrupt when IC1F flag is set
EnableIntIC2   EQU $0200  ; interrupt when IC2F flag is set
EnableIntIC3   EQU $0400  ; interrupt when IC3F flag is set
EnableIntOC1   EQU $0800  ; interrupt when OC1F flag is set
EnableIntOC2   EQU $1000  ; interrupt when OC2F flag is set
EnableIntOC3   EQU $2000  ; interrupt when OC3F flag is set
EnableIntOC4   EQU $4000  ; interrupt when OC4F flag is set
EnableIntIC4   EQU $8000  ; interrupt when I4O5I flag is set
EnableIntTOI   EQU $0080  ; timer overflow interrupt enable
EnableIntPAOVI EQU $0020  ; interrupt when PAOVF flag is set 
EnableIntPAII  EQU $0010  ; interrupt when PAIF flag is set
CPROUT         EQU $0008  ; drive TCNT clock out on OC1 pin 
;* CPR     EQU 0   ; timer prescaler tap select
*
* LDA  PACTL
* ORAA #UseIC4
* ANDA #~UseIC4
* STA  PACTL
*
UseIC4  EQU $04 ; 1 = enable Input Capture 4; 0 = enable Output Compare 5
