	NOPAGE  ; supress pagination
*************************************************************************
* HSI2C_IP.ASM    Interfacing to an Altera MAX3000A PLD for HSI2C                                                
*
* Version: 1.1
*
* Ted Salazar 10/04/06
*
*
* This Program uses the MAX1169 HSI2C ADC with the 68HC16 and a 
* CPLD programmed with DCD's DI2CM High Speed I2C IP Core.
* The 68HC16 is using a 16MHz system clock.
*
* This Program defaults to 1.7MHz because of the MAX1169 but it is easily
* configured for 3.4MHz by editing the lines of the code shown below:

* Configure DI2CM for 1.7MHz or 3.4MHz for Address and Data Operations
* This line sets for 3.4MHz
*	LDAA #$81   ;write $04 to D7-D0 using the WR\ strobe  
* This line sets for 1.7MHz
*	LDAA #$83   ;write $04 to D7-D0 using the WR\ strobe  
 
*************************************************************************
* For use with Maxim 68HC16MODULE-DIP using rev 2 monitor
* Written for use with the Motorola 68HC Macro Assembler - Vers. 4.1
***************************************************************************
* Name  68HC16 Module
* RD\     pin-9
* WR\     pin-10
* CS\     pin-11 
* A00     pin-15
* A01     pin-16
* A02     pin-17
* A03     pin-18
* D0-D7  pin-19 thru pin-26
*
* memory-mapped I/O pins are: 
* The related strobes (ie, RD\, WR\, CS\, A0-A3 and D0-D7). 
* When you write data, RD\, WR\, and CS\ are controlled for you automatically.
* The address lines A3-A0 are selected as follows:
* A3 A2 A1 A0 = 0 0 0 0  => CS_AREA_0
* A3 A2 A1 A0 = 0 0 0 1  => (CS_AREA_0 + 1)
*  :    :   :   :                      
* A3 A2 A1 A0 = 0 1 1 1   => (CS_AREA_0 +7)

*  For example,
*	ldab #page(CS_AREA_0+7)
*	tbxk
*	ldx  #(CS_AREA_0+7)
*
*
* The Maximum Write Speed for a memory-mapped non-loop or non-branch write is: 
* Data bits, i.e. D0 can be toggled like a 192.3kHz clock or 384.6kbps
* D0 -->  high for 2.6us and low for 2.6us
* Thus the Maximum data rate for the "PARALLEL" lines would be 3.07Mbps
*                                                                       
*************************************************************************
	INCLUDE 'EVKIT2.ASM'  ;MAXIM Evaluation board with rev 2 rom
        INCLUDE 'GPT.ASM'     ;GPT constants and template
*************************************************************************
J3PIN33     EQU PINOC4  ; HSI2CMOD J3-33 = PINOC4 
PROMPT      EQU  '>'    ; command prompt character
SWSR        EQU $FA27   ;SOFTWARE SERVICE REGISTER
*************************************************************************

*****  Start of main program  *****
	org $010000
Main:	
	jmp  KIT_INIT
	jmp  KIT_CMD_HANDLER
	jmp  READ_ADC
	dc.w KIT_ID
	dc.w KIT_HELP

;-----------------------------------------
KIT_ID:
	dc 'HSI2C_IP 68HC16 10/04/06'
	dc 0
	even
;---------------------------
;---------------------------
KIT_HELP:
	dc CR
	dc CR
	dc CR
	dc ' This is Teds HS firmware only 8-bit memory-mapped IO template'	
	dc CR
	dc CR
	dc CR	
	dc 'W0xx = write the 8-bit hexadecimal byte (xx) to address 0'
	dc CR
	dc 'W1xx = write the 8-bit hexadecimal byte (xx) to address 1'
	dc CR
	dc 'W2xx = write the 8-bit hexadecimal byte (xx) to address 2'
	dc CR
	dc 'W3xx = write the 8-bit hexadecimal byte (xx) to address 3'
	dc CR
	dc CR		
	dc 'R0xx = read the 8-bit hexadecimal byte (xx) from address 0'
	dc CR
	dc 'R1xx = read the 8-bit hexadecimal byte (xx) from address 1'
	dc CR
	dc 'R2xx = read the 8-bit hexadecimal byte (xx) from address 2'
	dc CR
	dc 'R3xx = read the 8-bit hexadecimal byte (xx) from address 3'
	dc CR		
	dc CR
	dc ' Written by (^_^)   Written for <~_~> and (~_~)'
	dc 0
	even
;---------------------------

;---------------------------
KIT_INIT:
	ldab #Page(SampleArrayArea)
	tbzk                    ; tell ver 2.0 HandleDefaultCommand
	ldz  #SampleArrayArea   ; where the sample array will be stored
	jsr  SetSampleArrayStart

        ldab #Page(globals)
        tbyk
        ldy  #globals	
	
	jsr  InitADC            ; initialize the A/D converter
	jmp  STANDARD_KIT       ; jump to standard EV KIT command loop

;----------------------------------------
InitADC:

	LDAB #PAGE(TestMessage1)
        TBXK
        LDX  #TestMessage1
        JSR  TX_MESSAGE

;Initialize CPLD
	; Set HSI2CMOD J3-33 line as an output
	LDAA #$40
	STAA PDDR

;CPLD needs to be reset after power up.
	; Set HSI2CMOD J3-33 line initially low
	LDAA #$00
	STAA GPTPDR

        NOP
        NOP
     
	BSET GPTPDR,#J3PIN33  	;J3PIN33 high

        NOP
        NOP
     	
	BCLR GPTPDR,#J3PIN33  	;J3PIN33 low
;	
;W304: Configure DI2CM for 400kHz for Master Code send rate
	ldab #page(CS_AREA_0+3) ; Set to Address 3
	tbxk
	ldx  #(CS_AREA_0+3)
	
	LDAA #$04   ;write $04 to D7-D0 using the WR\ strobe  
	STAA 0,x

        NOP
        NOP
 
;W383: Configure DI2CM for 1.7MHz or 3.4MHz for Address and Data Operations
;This line sets for 3.4MHz
;	LDAA #$81   ;write $04 to D7-D0 using the WR\ strobe  
;This line sets for 1.7MHz
	LDAA #$83   ;write $04 to D7-D0 using the WR\ strobe  

	STAA 0,x

        NOP
        NOP
 
 
;W008: Configure the value of the Master Code
;LOOP:	
	ldab #page(CS_AREA_0) ; Set to Address 0
	tbxk
	ldx  #(CS_AREA_0)

	LDAA #$08   ;write $08 to D7-D0 using the WR\ strobe  
	STAA 0,x

        NOP
        NOP
 
 
;W111: Do a Master Code Send operation
	ldab #page(CS_AREA_0+1) ; Set to Address 0
	tbxk
	ldx  #(CS_AREA_0+1)

	LDAA #$11   ;write $11 to D7-D0 using the WR\ strobe  
	STAA 0,x

;These specific delays below are required by the DI2CM!
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

;W07F: Configure the I2C Slave Address
	ldab #page(CS_AREA_0) ; Set to Address 0
	tbxk
	ldx  #(CS_AREA_0)

	LDAA #$7F   ;write $7F to D7-D0 using the WR\ strobe  
	STAA 0,x

        NOP
        NOP
 
;W10B: Do a HSI2C Address send + Read
	ldab #page(CS_AREA_0+1) ; Set to Address 0
	tbxk
	ldx  #(CS_AREA_0+1)

	LDAA #$0B   ;write $0B to D7-D0 using the WR\ strobe  
	STAA 0,x

;These specific delays below are required by the DI2CM!
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
 
;R2xx: Do a Data Read out of the CPLD's data register
	ldab #page(CS_AREA_0+2)
	tbxk
	ldx  #(CS_AREA_0+2)

	LDAA 0,x      ;read byte from Address 2
	STAA HexByte1,y
;        jsr TX_HEX    ;Echo the read byte on the terminal for debug


;W105: Do a HSI2C Read + Stop
	ldab #page(CS_AREA_0+1) ; Set to Address 0
	tbxk
	ldx  #(CS_AREA_0+1)

	LDAA #$05   ;write $05 to D7-D0 using the WR\ strobe  
	STAA 0,x

;These specific delays below are required by the DI2CM!
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP
        NOP

;R2xx: Do a Data Read out of the CPLD's data register
	ldab #page(CS_AREA_0+2)
	tbxk
	ldx  #(CS_AREA_0+2)

	LDAA 0,x      ;read byte from Address 2
	STAA HexByte2,y
;        jsr TX_HEX    ;Echo the read byte on the terminal for debug

; If you comment out the next three lines it will only toggle pin 27 for 30 seconds
	LDD #$55AA   			;reset software watchdog timer
	STAA SWSR    			;reset software watchdog timer
	STAB SWSR     			;reset software watchdog timer

;	BRA LOOP

	RTS
;----------------------------------------



;---------------------------
KIT_CMD_HANDLER:       ; handle commands specific to the MAX1169



READ_ADC:
        rts

;--------------------------
TestMessage1:
	DC   CR
	DC   'Starting Teds HSI2C_IP.ASM program'
	DC   CR
	DC   CR
	DC   NULL
	even
	rts
;---------------------------
TestMessageA:
	DC   CR
	DC   'This program currently only supports writing/reading to Address 0,1,2 and 3'
	DC   CR
	DC   CR
	DC   NULL
	even
	rts
;---------------------------
	
;---------------------------
globals:
	org 0
	
HexByte1: ds 1
HexByte2: ds 1
	
	org globals
;---------------------------
	org $011000
SampleArrayArea: ds 2
;----------------------------------------

       END  MAIN  		   	; Should never reach END when looping
