;* --------------------------------------------------------------------------------------
;*  Ted Salazar    (^_^)
;* --------------------------------------------------------------------------------------
;*  Filename:      listing1.asm
;*  Date:          June 21, 2005
;*  Version:       1.00
;*
;*  Description:   Main assembly source file for the AppNote titled,
;*                 "MAXQ an Audio/Video Source Selector, MAX4397 Style"
;* --------------------------------------------------------------------------------------
;*  Dev Tools:     MAX-IDE Version 1.0 
;*
;*  Hardware:      MAX4397EVKIT
;*                 MAXQ2000-KIT
;*
;*  Hardware Setup:MAX4397EVKIT: All jumpers in default locations
;*                               See the MAX4397EVKIT Data Sheet  
;*                 MAXQ2000-KIT: All jumpers in default locations
;*                               See the MAXQ2000-KIT Data Sheet
;*                  All dip switches set as follows:
;*                  SW1.1 ON  
;*                  SW1.2 ON  
;*                  SW1.3 OFF  
;*                  SW1.4 OFF 
;*                  SW1.5 OFF
;*                  SW1.6 ON 
;*                  SW1.7 OFF 
;*                  SW1.8 ON 
;*
;*                  SW3.1 ON 
;*                  SW3.2 ON 
;*                  SW3.3 OFF 
;*                  SW3.4 OFF 
;*                  SW3.5 OFF
;*                  SW3.6 ON 
;*                  SW3.7 OFF 
;*                  SW3.8 OFF 
;*
;*                  SW6.1 OFF 
;*                  SW6.2 ON 
;*                  SW6.3 ON 
;*                  SW6.4 ON 
;*                  SW6.5 ON 
;*                  SW6.6 OFF
;*                  SW6.7 OFF 
;*                  SW6.8 ON 
;*
;* --------------------------------------------------------------------------------------
$include(maxQ2000.inc)

org 0
    call Init_MAXQ_4_4397APP
    call Init_MAX4397    
    sjump $

;*****************************************************************************
;
; interrupt_handler:
;
; interrupts affected: External Interrupt 10 (SW4)
;                      External Interrupt 15 (SW5)
; 
;*****************************************************************************
interrupt_handler:
    move  APC, #0
    move  AP, #0                       ; select A[3] for our accumulator
    move  ACC, EIF1                    ; get the interrupt flag
    and   #80h                         ; check for interrupt 15
    jump  z, interrupt_not_15
    ;
    ; External interrupt 15 (SW5) fired.  
    ;
    call  A_V_Source_2_To_TV
    ; 
    ; Fallthrough to check for the other interrupt
    ;
interrupt_not_15:
    move  ACC, EIF1                    ; get the interrupt flag
    and   #04h                         ; check for interrupt 10
    jump  z, interrupt_not_10
    ;
    ; External interrupt 10 (SW4) fired.  
    ;
    call  A_V_Source_1_To_TV              
 
interrupt_not_10:
    move  EIF1, #0                     ; clear the interrupts
    reti

;*****************************************************************************
;
;  Function:    A_V_Source_1_To_TV
; 
;  Description: Audio/Video Source 1 to TV
;               1)WriteByte#1: TV_Y/CVBS_OUT = TV_Y/CVBS_IN
;               2)WriteByte#2: TV_OUT_ =TV_IN_
;               
;              
;  Input:       None
;
;  Output:      c - set on error (no ACK)
;
;*****************************************************************************
A_V_Source_1_To_TV:
   ;
   ; WriteByte#1: TV_Y/CVBS_OUT = TV_Y/CVBS_IN 
   ;
   call    I2C_Start
   move    Acc, #0096h                 ; Slave Addr
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_1_To_TV_NoACK
   move    Acc, #0006h                 ; Reg
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_1_To_TV_NoACK
   move    Acc, #001Bh                 ; Data
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_1_To_TV_NoACK
   call    I2C_Stop
   ;
   ; WriteByte#2: TV_OUT_ =TV_IN_
   ;
   call    I2C_Start
   move    Acc, #0096h                 ; Slave Addr
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_1_To_TV_NoACK
   move    Acc, #0001h                 ; Reg
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_1_To_TV_NoACK
   move    Acc, #000Eh                 ; Data
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_1_To_TV_NoACK
   call    I2C_Stop

   move    C, #0                       ; denote no error

A_V_Source_1_To_TV_NoACK:
   call    I2C_Stop
   ret

;*****************************************************************************
;
;  Function:    A_V_Source_2_To_TV
; 
;  Description: Audio/Video Source 2 to TV
;               1)WriteByte#1: TV_Y/CVBS_OUT = VCR_Y/CVBS_IN
;               2)WriteByte#2: TV_OUT_ = VCR_IN_
;               
;              
;  Input:       None
;
;  Output:      c - set on error (no ACK)
;
;*****************************************************************************
A_V_Source_2_To_TV:
   ;
   ;  WriteByte#1: TV_Y/CVBS_OUT = VCR_Y/CVBS_IN
   ;
   move    A[1], ACC
   call    I2C_Start
   move    Acc, #0096h                 ; Slave Addr
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_2_To_TV_NoACK
   move    Acc, #0006h                 ; Reg
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_2_To_TV_NoACK
   move    Acc, #001Ah                 ; Data
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_2_To_TV_NoACK
   call    I2C_Stop
   ;
   ; WriteByte#2: TV_OUT_ = VCR_IN_
   ;
   call    I2C_Start
   move    Acc, #0096h                 ; Slave Addr
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_2_To_TV_NoACK
   move    Acc, #0001h                 ; Reg
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_2_To_TV_NoACK
   move    Acc, #000Dh                 ; Data
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, A_V_Source_2_To_TV_NoACK
   call    I2C_Stop

   move    C, #0                       ; denote no error

A_V_Source_2_To_TV_NoACK:
   call    I2C_Stop
   ret

end
