;* --------------------------------------------------------------------------------------
;*  Ted Salazar    (^_^)
;* --------------------------------------------------------------------------------------
;*  Filename:      maxq2000_4397.asm
;*  Date:          June 21, 2005
;*  Version:       1.00
;*   
;*  Description:   This is a customized driver file for the MAX4397.
;*
;* --------------------------------------------------------------------------------------
$include(..\api\maxQ2000.inc)

#define SCL_ON   M1[18].0   ; PD6.0
#define SDA_ON   M1[18].1   ; PD6.1
#define SCL      M1[2].0    ; PO6.0
#define SDA      M1[2].1    ; PO6.1
#define SDA_IN   M1[10].1   ; PI6.1

;*****************************************************************************
;
;  Function:    Init_MAX4397
; 
;  Description: MAX4397 initialization for the MAX4397 APPNOTE:
;               1)WriteByte#1: Enable TV_Y/CVBS_OUT
;               2)WriteByte#2: Disable TV Audio Mute
;               
;              
;  Input:       None
;
;  Output:      c - set on error (no ACK)
;
;*****************************************************************************
Init_MAX4397:
   ;
   ; WriteByte#1: Enable TV_Y/CVBS_OUT
   ;
   call    I2C_Start
   move    Acc, #0096h                 ; Slave Addr
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, Init_MAX4397_NoACK
   move    Acc, #000Dh                 ; Reg
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, Init_MAX4397_NoACK
   move    Acc, #0004h                 ; Data
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, Init_MAX4397_NoACK
   call    I2C_Stop
   ;
   ; WriteByte#2: Disable TV Audio Mute
   ;
   call    I2C_Start
   move    Acc, #0096h                 ; Slave Addr
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, Init_MAX4397_NoACK
   move    Acc, #0000h                 ; Reg
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, Init_MAX4397_NoACK
   move    Acc, #0046h                 ; Data
   call    I2C_TxByte
   call    I2C_RxBit                   ; ACK
   jump    C, Init_MAX4397_NoACK
   call    I2C_Stop

   move    C, #0                       ; denote no error

Init_MAX4397_NoACK:
   call    I2C_Stop
   ret

;********************************************************************
;
;  Function:    Init_MAXQ_4_4397APP
;
;  Description: MAXQ initialization for the MAX4397 APPNOTE:
;               1)Normal Setting for Accumulator Controls
;               2)Set Interrupt Vector
;               3)Set Data Pointer Controls 
;              
;  Input:       None
; 
;  Output:      None
; 
;********************************************************************
Init_MAXQ_4_4397APP:  
   move  APC, #0                      ; no accumulator-modulo behavior
   move  AP, #0                       ; select accumulator 0
   move  DPC, #0                      ; select DP[0], byte mode
   move  IV, #interrupt_handler       ; set interrupt vector

   call  init_push_buttons            ; setup push button configuration
   move  ACC, IMR                     ; need to mask in module 0 interrupts
   or    #1                           ; low bit --> module 0
   move  IMR, ACC                     ; store new interrupt mask
   move  IC, #1                       ; initialize global interrupts
   call  I2C_Init  
   ret 

;*****************************************************************************
;
; Function:    init_push_buttons
;
; Description: Initialize the push buttons.  We will be using push buttons 10 (SW4) 
;              and 15 (SW5) in this application.  Set for falling edge triggered 
;              interrupts.  Enables interrupts from module 1 in the system 
;              interrupt mask.
;
; Input:       None
; Output:      None
; Destroyed:   ACC, PSW
;
;*****************************************************************************
init_push_buttons:
    move  EIE1, #84h                   ; enable interrupts for EI 10 and 15
    move  EIES1, #84h                  ; select falling edge for EI 10 and 15
    move  ACC, IMR                     ; get the interrupt mask enable
    or    #2                           ; include interrupts for module 1
    move  IMR, ACC                     ; store new interrupt mask enable value
    ret

;********************************************************************
;*
;* Function:    I2C_Init
;*
;* Description: Initialize the I2C lines on the MAXQ2000 Evaluation 
;*              Kit.
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    None
;*
;********************************************************************
I2C_Init:
   move    SCL, #1
   move    SDA, #1
   move    SCL_ON, #1
   move    SDA_ON, #1
   ret

;********************************************************************
;*
;* Function:    Pause
;*
;* Description: Performs a fixed pause for I2C communications.
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    LC[0]
;*
;********************************************************************
Pause:
   move    LC[0], #0030    ;T => ~113kHz w/ 16MHz Crystal
   djnz    LC[0], $
   ret   


;********************************************************************
;*
;* Function:    PauseWrite
;*
;* Description: Performs a fixed pause suitable for an I2C write
;*              delay.
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    LC[0], LC[1]
;*
;********************************************************************
PauseWrite:
    move    LC[0], #0030    ;T => ~113kHz w/ 16MHz Crystal
	move    LC[1], #003    ;T => ~113kHz w/ 16MHz Crystal
PauseWrite_L1:
   djnz    LC[0], $
   djnz    LC[1], PauseWrite_L1
   ret   

;********************************************************************
;*
;* Function:    I2C_Start
;*
;* Description: Performs a START condition on the I2C bus.
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    LC[0]
;*
;********************************************************************
I2C_Start:
   move    SCL, #1           ; Drive HIGH
   move    SDA, #1           ; Drive HIGH
   call    Pause
   move    SDA, #0           ; Drive LOW
   call    Pause
   move    SCL, #0           ; Drive LOW
   call    Pause
   ret

;********************************************************************
;*
;* Function:    I2C_Stop
;*
;* Description: Performs a STOP condition on the I2C bus.  Assumes 
;*              that SCL/SDA are LOW.
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    LC[0]
;*
;********************************************************************
I2C_Stop:
   call    Pause
   move    SCL, #1           ; Drive HIGH
   call    Pause
   move    SDA, #1           ; Drive HIGH
   call    Pause
   ret


;********************************************************************
;*
;* Function:    I2C_TxBit
;*
;* Description: Transmits a 0/1 data bit on the I2C bus.  Assumes 
;*              that SCL/SDA are LOW.
;*
;* Input:       c - bit to output on the I2C bus
;*
;* Output:      None
;*
;* Destroys:    LC[0]
;*
;********************************************************************
I2C_TxBit:
   jump    C, I2C_TxBitHi
   move    SDA, #0           ; Drive LOW
   jump    I2C_TxBitClk
I2C_TxBitHi:
   move    SDA, #1           ; Drive HIGH
I2C_TxBitClk:
   call    Pause
   move    SCL, #1           ; Raise clock
   call    Pause
   move    SCL, #0           ; Lower clock
   call    Pause
   move    SDA, #0           ; Clear SDA to low
   call    Pause
   ret

;********************************************************************
;*
;* Function:    I2C_RxBit
;*
;* Description: Receives a data bit from the I2C bus.  Assumes that 
;*              SCL/SDA are LOW.
;*
;* Input:       None
;*
;* Output:      c - bit input from the I2C bus
;*
;* Destroys:    LC[0]
;*
;********************************************************************
I2C_RxBit:
   move    SDA_ON, #0        ; Release data line
   move    SDA, #1           ; Weak pullup
   call    Pause
   move    SCL, #1           ; Raise clock
   call    Pause
   move    C, SDA_IN         ; Get bit output from slave
   call    Pause
   move    SCL, #0           ; Lower clock
   call    Pause
   move    SDA, #0           ; Turn off weak pullup
   move    SDA_ON, #1        ; Drive LOW
   call    Pause
   ret

;********************************************************************
;*
;* Function:    I2C_TxByte
;*
;* Description: Transmits a 8-bit byte on the I2C bus.  Assumes that 
;*              SCL/SDA are LOW.
;*
;* Input:       ACC - byte to transmit on I2C
;*
;* Output:      c - bit input from the I2C bus
;*
;* Destroys:    LC[0], PSF
;*
;********************************************************************
I2C_TxByte:
   xch                       ; Move transmit byte to high byte
   rlc
   call    I2C_TxBit         ; Transmit bit 7
   rlc
   call    I2C_TxBit         ; Transmit bit 6
   rlc
   call    I2C_TxBit         ; Transmit bit 5
   rlc
   call    I2C_TxBit         ; Transmit bit 4
   rlc
   call    I2C_TxBit         ; Transmit bit 3
   rlc
   call    I2C_TxBit         ; Transmit bit 2
   rlc
   call    I2C_TxBit         ; Transmit bit 1
   rlc
   call    I2C_TxBit         ; Transmit bit 0
   ret

;********************************************************************
;*
;* Function:    I2C_RxByte
;*
;* Description: Receives an 8-bit byte from a slave on the I2C bus, 
;*              MSB first.
;*              
;* Input:       None
;*
;* Output:      ACC - bbyte received over I2C
;*
;* Destroys:    LC[0], PSF
;*
;********************************************************************
I2C_RxByte:
   move    Acc, #0000h       ; Clear accumulator
   call    I2C_RxBit         ; Receive bit 7
   rlc                       ; Shift bit into Acc
   call    I2C_RxBit         ; Receive bit 6
   rlc
   call    I2C_RxBit         ; Receive bit 5
   rlc
   call    I2C_RxBit         ; Receive bit 4
   rlc
   call    I2C_RxBit         ; Receive bit 3
   rlc
   call    I2C_RxBit         ; Receive bit 2
   rlc
   call    I2C_RxBit         ; Receive bit 1
   rlc
   call    I2C_RxBit         ; Receive bit 0
   rlc
   ret

end
